// vi: set ts=4 sw=4 :
// vim: set tw=75 :

/*
 * Copyright (c) 2004 OLO
 * This file is a part of PLBot application.
 * You are not allowed to remove these copyrights.
 */

#include <extdll.h>   // always

#include <api_info.h>  // api_info_t, etc
#include <sdk_util.h>  // REG_SVR_COMMAND, etc
#include <meta_api.h>  // Plugin_info, etc
#include <cbase.h>

#include "plbot_api.h"  // me
#include "vers_plugin.h"   // COMPILE_TIME

cvar_t *plbot_version;
cvar_t *plb_control;
cvar_t *plb_group;
cvar_t *plb_skill;
cvar_t *plb_password;
cvar_t *plb_config;
cvar_t *plb_wptdir;
cvar_t *plb_pause;
cvar_t *plb_canchat;
cvar_t *plb_onlywpt;
cvar_t *plb_autoadd;
cvar_t *plb_number;
cvar_t *plb_jointime;

cvar_t init_plbot_version = {"plbot_version",VVERSION, FCVAR_SERVER | FCVAR_SPONLY};
cvar_t init_plb_control = {"plb_control","2",0,2.0};
cvar_t init_plb_group = {"plb_group","2",0,2.0};
cvar_t init_plb_skill = {"plb_skill","2",0,2.0};
cvar_t init_plb_config = {"plb_config","plbot/plbot.cfg",0};
cvar_t init_plb_wptdir = {"plb_wptdir","plbot/maps/",0};
cvar_t init_plb_password = {"plb_password","",0}; //Disabled by default
cvar_t init_plb_pause = {"plb_pause","0",0,0.0};
cvar_t init_plb_canchat = {"plb_canchat","1",0,1.0};
cvar_t init_plb_onlywpt = {"plb_onlywpt","1",0,1.0};
cvar_t init_plb_autoadd = {"plb_autoadd","0",0,0.0};
cvar_t init_plb_number = {"plb_number","0",0,0.0};
cvar_t init_plb_jointime = {"plb_jointime","60.0",0,60.0};

names_s bot_names[MAX_BOT_NAMES];
chat_s chat_text[MAX_BOT_CHAT];

int chat_num = 0;

int prev_nick = 0;

void CmdAddNewChat()
{
   const char *pArg1 = CMD_ARGV(1);
   if (chat_num<MAX_BOT_CHAT&&CMD_ARGC()>1)
   {
      free(chat_text[chat_num].text);
      chat_text[chat_num].text = (char*)malloc(strlen(pArg1)+1);
      strcpy(chat_text[chat_num].text, pArg1);
      chat_num++;
   }
}

void CmdAddNewName()
{
   const char *pArg1 = CMD_ARGV(1);
   if (number_names<MAX_BOT_NAMES&&CMD_ARGC()>1)
   {
      free(bot_names[number_names].name);
      bot_names[number_names].name = (char*)malloc(strlen(pArg1)+1);
      strcpy(bot_names[number_names].name, pArg1);
      number_names++;
      prev_nick = number_names;
   }
}

void PLBotAddBot(void)
{
   const char *pArg1 = CMD_ARGV(1);
   const char *pArg2 = CMD_ARGV(2);
   BotCreate( NULL, pArg1, pArg2);
}

void CmdCreateNewCvar()
{
   const char *pArg1 = CMD_ARGV(1);
   const char *pArg2 = CMD_ARGV(2);
   const char *pArg3 = CMD_ARGV(3);

   if (cvars_num<MAX_CVAR&&CMD_ARGC() > 1)
   {
      free(cvar_game[cvars_num].name);
      cvar_game[cvars_num].name = (char*)malloc(strlen(pArg1) + 1);
      strcpy(cvar_game[cvars_num].name, pArg1);

      if (CMD_ARGC() > 3)
      {
         cvar_game[cvars_num].step = atof(pArg2);
         cvar_game[cvars_num].max = atof(pArg3);
      }
      else
      {
         cvar_game[cvars_num].step = 1.0;
         cvar_game[cvars_num].max = 1.0;
      }

      cvars_num++; //Increase number of cvars_num for menu
   }
}

void CmdCreateNewCmd()
{
   const char *pCmd = CMD_ARGV(0);
   const char *pArg1 = CMD_ARGV(1);
   const char *pArg2 = CMD_ARGV(2);

   if (cstcmd_num<MAX_CMD&&CMD_ARGC()>2)
   {
      free(cstcmd_names[cstcmd_num].cmd);
      free(cstcmd_names[cstcmd_num].cmd_d);
      cstcmd_names[cstcmd_num].cmd = (char*)malloc(strlen(pArg2)+1);
      strcpy(cstcmd_names[cstcmd_num].cmd, pArg2);
      cstcmd_names[cstcmd_num].cmd_d = (char*)malloc(strlen(pArg1)+1);
      strcpy(cstcmd_names[cstcmd_num].cmd_d, pArg1);
      cstcmd_num++;
   }
}


// Plugin startup.  Register commands and cvars.
void plbot_init(void)
{
   LOG_MESSAGE(PLID, "%s %s, %s", Plugin_info.name, Plugin_info.version, Plugin_info.date);
   LOG_MESSAGE(PLID, "by %s", Plugin_info.author);
   LOG_MESSAGE(PLID, "   http://%s/", Plugin_info.url);
   LOG_MESSAGE(PLID, "compiled: %s", __DATE__ ", " __TIME__);

   CVAR_REGISTER (&init_plbot_version);
   CVAR_REGISTER (&init_plb_autoadd);
   CVAR_REGISTER (&init_plb_canchat);
   CVAR_REGISTER (&init_plb_config);
   CVAR_REGISTER (&init_plb_control);
   CVAR_REGISTER (&init_plb_group);
   CVAR_REGISTER (&init_plb_jointime);
   CVAR_REGISTER (&init_plb_number);
   CVAR_REGISTER (&init_plb_onlywpt);
   CVAR_REGISTER (&init_plb_password);
   CVAR_REGISTER (&init_plb_pause);
   CVAR_REGISTER (&init_plb_skill);
   CVAR_REGISTER (&init_plb_wptdir);

   plbot_version = CVAR_GET_POINTER("plbot_version");
   plb_autoadd = CVAR_GET_POINTER("plb_autoadd");
   plb_canchat = CVAR_GET_POINTER("plb_canchat");
   plb_config = CVAR_GET_POINTER("plb_config");
   plb_control = CVAR_GET_POINTER("plb_control");
   plb_group = CVAR_GET_POINTER("plb_group");
   plb_skill = CVAR_GET_POINTER("plb_skill");
   plb_password = CVAR_GET_POINTER("plb_password");
   plb_wptdir = CVAR_GET_POINTER("plb_wptdir");
   plb_pause = CVAR_GET_POINTER("plb_pause");
   plb_onlywpt = CVAR_GET_POINTER("plb_onlywpt");
   plb_number = CVAR_GET_POINTER("plb_number");
   plb_jointime = CVAR_GET_POINTER("plb_jointime");

   memset(bots, 0, sizeof(bots)); //Clear memory

   REG_SVR_COMMAND("plb_add",PLBotAddBot);
   REG_SVR_COMMAND("plb_chat",CmdAddNewChat);
   REG_SVR_COMMAND("plb_cmd",CmdCreateNewCmd);
   REG_SVR_COMMAND("plb_cvar",CmdCreateNewCvar);
   REG_SVR_COMMAND("plb_name",CmdAddNewName);

   parameters[0] = 1600; //maxway
   parameters[1] = 40; //bsenss
   parameters[2] = 120; //bsensf
   parameters[3] = 24; //blevel
   parameters[4] = 164; //bheight
   parameters[5] = 96; //bunstuck
   parameters[6] = 32; //minway
   parameters[7] = 15; //bangle
   parameters[8] = 1; //showway //Not used
   parameters[9] = 4; //bprio
   parameters[10] = 5; //blnodes //Memmory
   parameters[11] = 640; //bsee
   parameters[12] = 896; //btrace
   parameters[MAX_PARM - 2] = 1;//group
   parameters[MAX_PARM - 1] = 2;//control
}
